searchNodes=[{"doc":"This module provides FIFO queues in an efficient manner. FiFo is just a rewrite of the Erlang module queue in an Elixir way. The module includes implementations of the protocols Enumerabale , Collectable , and Inspect .","ref":"FiFo.html","title":"FiFo","type":"module"},{"doc":"Given a list of queues , concatenates the queues into a single queue. The first queue in the list becomes the front of the queue. Examples iex&gt; FiFo . concat ( [ ...&gt; FiFo . from_range ( 1 .. 3 ) , FiFo . from_range ( 4 .. 5 ) , FiFo . from_range ( 7 .. 9 ) ...&gt; ] ) # FiFo &lt; [ 1 , 2 , 3 , 4 , 5 , 7 , 8 , 9 ] &gt;","ref":"FiFo.html#concat/1","title":"FiFo.concat/1","type":"function"},{"doc":"Concatenates the queue b with the queue a with queue a in front of queue b . Examples iex&gt; FiFo . concat ( FiFo . from_list ( [ 1 , 2 ] ) , FiFo . from_list ( [ 3 , 4 ] ) ) # FiFo &lt; [ 1 , 2 , 3 , 4 ] &gt;","ref":"FiFo.html#concat/2","title":"FiFo.concat/2","type":"function"},{"doc":"Drops the amount of elements from the queue . If a negative amount is given, the amount of last values will be dropped. Examples iex&gt; [ 1 , 2 , 3 ] |&gt; FiFo . from_list ( ) |&gt; FiFo . drop ( 2 ) # FiFo &lt; [ 3 ] &gt; iex&gt; [ 1 , 2 , 3 ] |&gt; FiFo . from_list ( ) |&gt; FiFo . drop ( - 2 ) # FiFo &lt; [ 1 ] &gt; iex&gt; [ 1 , 2 , 3 ] |&gt; FiFo . from_list ( ) |&gt; FiFo . drop ( 10 ) # FiFo &lt; [ ] &gt; iex&gt; [ 1 , 2 , 3 ] |&gt; FiFo . from_list ( ) |&gt; FiFo . drop ( 0 ) # FiFo &lt; [ 1 , 2 , 3 ] &gt;","ref":"FiFo.html#drop/2","title":"FiFo.drop/2","type":"function"},{"doc":"Determines if the queue is empty. Returns true if queue is empty, otherwise false . Examples iex&gt; FiFo . empty? ( FiFo . new ( ) ) true iex&gt; FiFo . empty? ( FiFo . from_list ( [ 1 ] ) ) false","ref":"FiFo.html#empty?/1","title":"FiFo.empty?/1","type":"function"},{"doc":"Fetches element at the front of queue . If queue is not empty, then {:ok, element} is returned. If queue is empty :error is returned. Examples iex&gt; FiFo . fetch ( FiFo . from_list ( [ 1 , 2 ] ) ) { :ok , 1 } iex&gt; FiFo . fetch ( FiFo . new ( ) ) :error","ref":"FiFo.html#fetch/1","title":"FiFo.fetch/1","type":"function"},{"doc":"Fetches element at the front of queue , erroring out if queue is empty. If queue is not empty, then {:ok, element} is returned. If queue is empty a FiFo.EmptyError excepetion is raised. Examples iex&gt; FiFo . fetch! ( FiFo . from_list ( [ 1 , 2 ] ) ) 1 iex&gt; FiFo . fetch! ( FiFo . new ( ) ) ** (FiFo.EmptyError) empty error","ref":"FiFo.html#fetch!/1","title":"FiFo.fetch!/1","type":"function"},{"doc":"Fetches element at the rear of queue . If queue is not empty, then {:ok, element} is returned. If queue is empty :error is returned. Examples iex&gt; FiFo . fetch_reverse ( FiFo . from_list ( [ 1 , 2 ] ) ) { :ok , 2 } iex&gt; FiFo . fetch_reverse ( FiFo . new ( ) ) :error","ref":"FiFo.html#fetch_reverse/1","title":"FiFo.fetch_reverse/1","type":"function"},{"doc":"Fetches element at the rear of queue , erroring out if queue is empty. If queue is not empty, then {:ok, element} is returned. If queue is empty a FiFo.EmptyError excepetion is raised. Examples iex&gt; FiFo . fetch! ( FiFo . from_list ( [ 1 , 2 ] ) ) 1 iex&gt; FiFo . fetch! ( FiFo . new ( ) ) ** (FiFo.EmptyError) empty error","ref":"FiFo.html#fetch_reverse!/1","title":"FiFo.fetch_reverse!/1","type":"function"},{"doc":"Filters the queue, i.e. returns only those elements for which fun returns a truthy value. See also reject/2 which discards all elements where the function returns a truthy value. Examples iex&gt; FiFo . filter ( FiFo . from_list ( [ 1 , 2 , 3 , 4 ] ) , fn x -&gt; rem ( x , 2 ) == 0 end ) # FiFo &lt; [ 2 , 4 ] &gt;","ref":"FiFo.html#filter/2","title":"FiFo.filter/2","type":"function"},{"doc":"Converts an Erlang queue to a queue. Examples iex&gt; FiFo . from_erlang_queue ( { [ 3 , 2 ] , [ 1 ] } ) # FiFo &lt; [ 1 , 2 , 3 ] &gt;","ref":"FiFo.html#from_erlang_queue/1","title":"FiFo.from_erlang_queue/1","type":"function"},{"doc":"Converts a list to a queue. Examples iex&gt; FiFo . from_list ( [ 1 , 2 , 3 ] ) # FiFo &lt; [ 1 , 2 , 3 ] &gt;","ref":"FiFo.html#from_list/1","title":"FiFo.from_list/1","type":"function"},{"doc":"Converts a range to a queue . Examples iex&gt; FiFo . from_range ( 1 .. 3 ) # FiFo &lt; [ 1 , 2 , 3 ] &gt;","ref":"FiFo.html#from_range/1","title":"FiFo.from_range/1","type":"function"},{"doc":"Gets element at the front of queue , erroring out if queue is empty. If queue is empty default is returned. If default is not provided, nil is used. Examples iex&gt; FiFo . get ( FiFo . from_list ( [ 1 , 2 ] ) ) 1 iex&gt; FiFo . get ( FiFo . new ( ) ) nil iex&gt; FiFo . get ( FiFo . new ( ) , :empty ) :empty","ref":"FiFo.html#get/2","title":"FiFo.get/2","type":"function"},{"doc":"Gets element at the rear of queue , erroring out if queue is empty. If queue is empty default is returned. If default is not provided, nil is used. Examples iex&gt; FiFo . get_reverse ( FiFo . from_list ( [ 1 , 2 ] ) ) 2 iex&gt; FiFo . get_reverse ( FiFo . new ( ) ) nil iex&gt; FiFo . get_reverse ( FiFo . new ( ) , :empty ) :empty","ref":"FiFo.html#get_reverse/2","title":"FiFo.get_reverse/2","type":"function"},{"doc":"Returns a queue where each element is the result of invoking fun on each corresponding element of queue . Examples iex&gt; FiFo . map ( FiFo . from_list ( [ 1 , 2 , 3 ] ) , fn x -&gt; x + 2 end ) # FiFo &lt; [ 3 , 4 , 5 ] &gt;","ref":"FiFo.html#map/2","title":"FiFo.map/2","type":"function"},{"doc":"Checks if element exists within the queue . Examples iex&gt; FiFo . member? ( FiFo . from_list ( [ 1 , 2 , 3 ] ) , 2 ) true iex&gt; FiFo . member? ( FiFo . from_list ( [ 1 , 2 , 3 ] ) , 6 ) false","ref":"FiFo.html#member?/2","title":"FiFo.member?/2","type":"function"},{"doc":"Returns an empty queue. Examples iex&gt; FiFo . new ( ) # FiFo &lt; [ ] &gt;","ref":"FiFo.html#new/0","title":"FiFo.new/0","type":"function"},{"doc":"Removes the element at the front of the queue. Returns tuple {{value, element}, queue} , where queue is the remaining queue. If the queue is empty a tuple {:error, %FiFo{}} is returned. Examples iex&gt; queue = FiFo . from_list ( [ 1 , 2 , 3 ] ) iex&gt; FiFo . pop ( queue ) == { { :ok , 1 } , FiFo . drop ( queue , 1 ) } true iex&gt; FiFo . new ( ) |&gt; FiFo . pop ( ) == { :error , % FiFo { } } true","ref":"FiFo.html#pop/1","title":"FiFo.pop/1","type":"function"},{"doc":"Removes the element at the front of the queue. Returns tuple {{value, element}, queue} , where queue is the remaining queue. If the queue is empty an EmptyError is raised. Examples iex&gt; queue = FiFo . from_list ( [ 1 , 2 , 3 ] ) iex&gt; FiFo . pop! ( queue ) == { 1 , FiFo . drop ( queue , 1 ) } true iex&gt; FiFo . pop! ( FiFo . new ( ) ) == { :error , % FiFo { } } ** (FiFo.EmptyError) empty error","ref":"FiFo.html#pop!/1","title":"FiFo.pop!/1","type":"function"},{"doc":"Removes the element at the rear of the queue. Returns tuple {{value, element}, queue} , where queue is the remaining queue. If the queue is empty a tuple {:error, %FiFo{}} is returned. Examples iex&gt; queue = FiFo . from_list ( [ 1 , 2 , 3 ] ) iex&gt; FiFo . pop_reverse ( queue ) == { { :ok , 3 } , FiFo . drop ( queue , - 1 ) } true iex&gt; FiFo . new ( ) |&gt; FiFo . pop_reverse ( ) == { :error , % FiFo { } } true","ref":"FiFo.html#pop_reverse/1","title":"FiFo.pop_reverse/1","type":"function"},{"doc":"Removes the element at the rear of the queue. Returns tuple {{value, element}, queue} , where queue is the remaining queue. If the queue is empty an EmptyError is raised. Examples iex&gt; queue = FiFo . from_list ( [ 1 , 2 , 3 ] ) iex&gt; FiFo . pop_reverse! ( queue ) == { 3 , FiFo . drop ( queue , - 1 ) } true iex&gt; FiFo . pop! ( FiFo . new ( ) ) == { :error , % FiFo { } } ** (FiFo.EmptyError) empty error","ref":"FiFo.html#pop_reverse!/1","title":"FiFo.pop_reverse!/1","type":"function"},{"doc":"Pushes an element to the rear of a queue. Examples iex&gt; queue = FiFo . new ( ) iex&gt; queue = FiFo . push ( queue , 2 ) # FiFo &lt; [ 2 ] &gt; iex&gt; FiFo . push ( queue , 4 ) # FiFo &lt; [ 2 , 4 ] &gt;","ref":"FiFo.html#push/2","title":"FiFo.push/2","type":"function"},{"doc":"Pushes an element to the front queue. Examples iex&gt; queue = FiFo . new ( ) iex&gt; queue = FiFo . push_reverse ( queue , 2 ) # FiFo &lt; [ 2 ] &gt; iex&gt; FiFo . push_reverse ( queue , 4 ) # FiFo &lt; [ 4 , 2 ] &gt;","ref":"FiFo.html#push_reverse/2","title":"FiFo.push_reverse/2","type":"function"},{"doc":"Returns a queue of elements in queue excluding those for which the function fun returns a truthy value. See also filter/2. Examples iex&gt; FiFo . reject ( FiFo . from_list ( [ 1 , 2 , 3 , 4 ] ) , fn x -&gt; rem ( x , 2 ) == 0 end ) # FiFo &lt; [ 1 , 3 ] &gt;","ref":"FiFo.html#reject/2","title":"FiFo.reject/2","type":"function"},{"doc":"Returns queue in reverse order. Examples iex&gt; FiFo . reverse ( FiFo . from_list ( [ 1 , 2 , 3 ] ) ) # FiFo &lt; [ 3 , 2 , 1 ] &gt;","ref":"FiFo.html#reverse/1","title":"FiFo.reverse/1","type":"function"},{"doc":"Returns the number of elements in queue . Examples iex&gt; FiFo . size ( FiFo . from_range ( 1 .. 42 ) ) 42","ref":"FiFo.html#size/1","title":"FiFo.size/1","type":"function"},{"doc":"Takes an amount of elements from the rear or the front of the queue . Returns a tuple with taken values and the remaining queue. If a negative amount is given, the amount of elements will be taken from rear. Examples iex&gt; queue = FiFo . from_range ( 1 .. 10 ) iex&gt; FiFo . take ( queue , 3 ) == { [ 1 , 2 , 3 ] , FiFo . drop ( queue , 3 ) } true iex&gt; FiFo . take ( queue , 0 ) == { [ ] , queue } true iex&gt; FiFo . take ( FiFo . new ( ) , 10 ) == { [ ] , FiFo . new ( ) } true","ref":"FiFo.html#take/2","title":"FiFo.take/2","type":"function"},{"doc":"Converts queue to an Erlang queue. Examples iex&gt; q = FiFo . to_erlang_queue ( FiFo . from_list ( [ 1 , 2 , 3 , 4 , 5 ] ) ) { [ 5 , 4 ] , [ 1 , 2 , 3 ] } iex&gt; q == :queue . from_list ( [ 1 , 2 , 3 , 4 , 5 ] ) true","ref":"FiFo.html#to_erlang_queue/1","title":"FiFo.to_erlang_queue/1","type":"function"},{"doc":"Converts queue to a list. Examples iex&gt; FiFo . to_list ( FiFo . from_range ( 1 .. 4 ) ) [ 1 , 2 , 3 , 4 ]","ref":"FiFo.html#to_list/1","title":"FiFo.to_list/1","type":"function"},{"doc":"","ref":"FiFo.html#t:element/0","title":"FiFo.element/0","type":"type"},{"doc":"","ref":"FiFo.html#t:empty/0","title":"FiFo.empty/0","type":"type"},{"doc":"","ref":"FiFo.html#t:front/0","title":"FiFo.front/0","type":"type"},{"doc":"","ref":"FiFo.html#t:rear/0","title":"FiFo.rear/0","type":"type"},{"doc":"","ref":"FiFo.html#t:t/0","title":"FiFo.t/0","type":"type"},{"doc":"","ref":"FiFo.EmptyError.html","title":"FiFo.EmptyError","type":"exception"}]